==> jc-1.4.0.tar.gz: java/lang/InheritableThreadLocal.h <==
// public class java.lang.InheritableThreadLocal

// class file dependencies
// @dep_class a2b69b02248b575c java_lang_InheritableThreadLocal
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb9becf335f12a20 java_lang_ThreadLocal

// header file dependencies
// @dep_header java_lang_ThreadLocal

#include "java/lang/ThreadLocal.h"

#ifndef _JC_java_lang_InheritableThreadLocal_H_
#define _JC_java_lang_InheritableThreadLocal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_Thread$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_lang_InheritableThreadLocal$sub_refs	_jc_java_lang_InheritableThreadLocal$sub_refs;
typedef struct _jc_java_lang_InheritableThreadLocal$sub_nonrefs	_jc_java_lang_InheritableThreadLocal$sub_nonrefs;
typedef struct _jc_java_lang_InheritableThreadLocal$refs	_jc_java_lang_InheritableThreadLocal$refs;
typedef struct _jc_java_lang_InheritableThreadLocal$nonrefs	_jc_java_lang_InheritableThreadLocal$nonrefs;
typedef struct _jc_java_lang_InheritableThreadLocal$object	_jc_java_lang_InheritableThreadLocal$object;

typedef struct _jc_java_lang_InheritableThreadLocal$fields_struct	_jc_java_lang_InheritableThreadLocal$fields_struct;
typedef const struct _jc_java_lang_InheritableThreadLocal$vmethods	_jc_java_lang_InheritableThreadLocal$vmethods;
typedef const struct _jc_java_lang_InheritableThreadLocal$vtable	_jc_java_lang_InheritableThreadLocal$vtable;
typedef const struct _jc_java_lang_InheritableThreadLocal$vtype	_jc_java_lang_InheritableThreadLocal$vtype;

// Class fields structure
struct _jc_java_lang_InheritableThreadLocal$fields_struct {
	struct _jc_object	*threadMap;
};
extern _jc_java_lang_InheritableThreadLocal$fields_struct _jc_java_lang_InheritableThreadLocal$class_fields;

// Constructors
extern void _jc_java_lang_InheritableThreadLocal$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_InheritableThreadLocal$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_InheritableThreadLocal$method$childValue$1b71f54ecca1e89d(_jc_env *, struct _jc_java_lang_InheritableThreadLocal$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_InheritableThreadLocal$method_info$childValue$1b71f54ecca1e89d;

// Static methods
extern void _jc_java_lang_InheritableThreadLocal$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_java_lang_InheritableThreadLocal$method$newChildThread$e96c94280eef2ddc(_jc_env *, struct _jc_java_lang_Thread$object *);

// Virtual methods structure
struct _jc_java_lang_InheritableThreadLocal$vmethods {
	struct _jc_java_lang_Object$object	*(*childValue$1b71f54ecca1e89d)(_jc_env *, struct _jc_java_lang_InheritableThreadLocal$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_lang_InheritableThreadLocal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ThreadLocal$vmethods	java_lang_ThreadLocal;
	_jc_java_lang_InheritableThreadLocal$vmethods	java_lang_InheritableThreadLocal;
};

// Vtype
struct _jc_java_lang_InheritableThreadLocal$vtype {
	_jc_type			type;
	_jc_java_lang_InheritableThreadLocal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_InheritableThreadLocal$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_InheritableThreadLocal$refs {
    _jc_java_lang_InheritableThreadLocal$sub_refs	java_lang_InheritableThreadLocal;
    _jc_java_lang_ThreadLocal$sub_refs	java_lang_ThreadLocal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_InheritableThreadLocal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_InheritableThreadLocal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ThreadLocal$sub_nonrefs	java_lang_ThreadLocal;
    _jc_java_lang_InheritableThreadLocal$sub_nonrefs	java_lang_InheritableThreadLocal;
};

// Object instance structure
struct _jc_java_lang_InheritableThreadLocal$object {
	_jc_java_lang_InheritableThreadLocal$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_InheritableThreadLocal$vtype	*vtype;
	_jc_java_lang_InheritableThreadLocal$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_InheritableThreadLocal$vtype _jc_java_lang_InheritableThreadLocal$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_InheritableThreadLocal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_InheritableThreadLocal$class_object;

#endif	/* _JC_java_lang_InheritableThreadLocal_H_ */

==> jc-1.4.6.tar.gz: java/lang/InheritableThreadLocal.h <==
// public class java.lang.InheritableThreadLocal

// class file dependencies
// @dep_class 444334c70a11ff67 java_lang_InheritableThreadLocal
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a0bc393bff0eefc java_lang_ThreadLocal

// header file dependencies
// @dep_header java_lang_ThreadLocal

#include "java/lang/ThreadLocal.h"

#ifndef _JC_java_lang_InheritableThreadLocal_H_
#define _JC_java_lang_InheritableThreadLocal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_Thread$object;

// Typedefs
typedef struct _jc_java_lang_InheritableThreadLocal$sub_refs	_jc_java_lang_InheritableThreadLocal$sub_refs;
typedef struct _jc_java_lang_InheritableThreadLocal$sub_nonrefs	_jc_java_lang_InheritableThreadLocal$sub_nonrefs;
typedef struct _jc_java_lang_InheritableThreadLocal$refs	_jc_java_lang_InheritableThreadLocal$refs;
typedef struct _jc_java_lang_InheritableThreadLocal$nonrefs	_jc_java_lang_InheritableThreadLocal$nonrefs;
typedef struct _jc_java_lang_InheritableThreadLocal$object	_jc_java_lang_InheritableThreadLocal$object;

typedef const struct _jc_java_lang_InheritableThreadLocal$vmethods	_jc_java_lang_InheritableThreadLocal$vmethods;
typedef const struct _jc_java_lang_InheritableThreadLocal$vtable	_jc_java_lang_InheritableThreadLocal$vtable;
typedef const struct _jc_java_lang_InheritableThreadLocal$vtype	_jc_java_lang_InheritableThreadLocal$vtype;

// Constructors
extern void _jc_java_lang_InheritableThreadLocal$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_InheritableThreadLocal$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_InheritableThreadLocal$method$childValue$1b71f54ecca1e89d(_jc_env *, struct _jc_java_lang_InheritableThreadLocal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_InheritableThreadLocal$method_info$childValue$1b71f54ecca1e89d;

// Static methods
extern void _jc_java_lang_InheritableThreadLocal$method$newChildThread$e96c94280eef2ddc(_jc_env *, struct _jc_java_lang_Thread$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_InheritableThreadLocal$vmethods {
	struct _jc_java_lang_Object$object	*(*childValue$1b71f54ecca1e89d)(_jc_env *, struct _jc_java_lang_InheritableThreadLocal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_InheritableThreadLocal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ThreadLocal$vmethods	java_lang_ThreadLocal;
	_jc_java_lang_InheritableThreadLocal$vmethods	java_lang_InheritableThreadLocal;
};

// Vtype
struct _jc_java_lang_InheritableThreadLocal$vtype {
	_jc_type			type;
	_jc_java_lang_InheritableThreadLocal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_InheritableThreadLocal$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_InheritableThreadLocal$refs {
    _jc_java_lang_InheritableThreadLocal$sub_refs	java_lang_InheritableThreadLocal;
    _jc_java_lang_ThreadLocal$sub_refs	java_lang_ThreadLocal;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_InheritableThreadLocal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_InheritableThreadLocal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ThreadLocal$sub_nonrefs	java_lang_ThreadLocal;
    _jc_java_lang_InheritableThreadLocal$sub_nonrefs	java_lang_InheritableThreadLocal;
};

// Object instance structure
struct _jc_java_lang_InheritableThreadLocal$object {
	_jc_java_lang_InheritableThreadLocal$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_InheritableThreadLocal$vtype	*vtype;
	_jc_java_lang_InheritableThreadLocal$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_InheritableThreadLocal$vtype _jc_java_lang_InheritableThreadLocal$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_InheritableThreadLocal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_InheritableThreadLocal$class_object;

#endif	/* _JC_java_lang_InheritableThreadLocal_H_ */
